PyTorch implementation of GMLS-Nets.

If you find these codes or methods helpful for your project, please cite: 

```
  @article{trask_patel_gross_atzberger_GMLS_Nets_2019,
    title={GMLS-Nets: A framework for learning from unstructured data},
    author={Nathaniel Trask, Ravi G. Patel, Ben J. Gross, Paul J. Atzberger},
    journal={arXiv:1909.05371},  
    month={September}
    year={2019}
    url={https://arxiv.org/abs/1909.05371}
  }
```  

Source code and additional information for this package available at <https://github.com/atzberg/gmls-nets>.

